@@ -5,10 +5,8 @@ This module provides collection
 of routines related to diis procedure
 """
 import logging
-import math
 from collections import deque
-from collections import namedtuple
-from types import SimpleNamespace
+
 
 import numpy as np
 
@@ -18,15 +16,6 @@ _initialized = False
 
 
 class Diis:
-    # def __init__(self, nd, like_array):
-    #     self.nd = nd
-    #     self.array_dim = like_array.shape
-    #
-    #     self.f = np.zeros((self.nd,) + self.array_dim)
-    #     self.df = np.zeros((self.nd,) + self.array_dim)
-    #     self.b = np.zeros([self.nd, self.nd])
-    #
-    #     self.kd = 0
 
     def __init__(self):
         self.f = deque([])
@@ -49,11 +38,11 @@ class Diis:
                 dij = self.df[i] * self.df[j]
                 a[i][j] = np.sum(dij) / ngrid
                 a[j][i] = a[i][j]
-        # print(a)
+
         b = np.zeros([nd + 1])
         b[nd] = -1
         x = np.linalg.solve(a, b)
-        # print(x)
+
         g = np.zeros(self.f[0].shape)
         for k in range(nd):
             g = g + x[k] * self.f[k]
@@ -94,5 +83,3 @@ def diis_session():
     return diis
 
 
-if __name__ == "__main__":
-    pass
