@@ -2,6 +2,8 @@ class ConvergenceError(Exception):
     def __init__(self, message=None):
         if message is None:
             message = "Convergence error"
+        else:
+            message = F"Convergence error: {message}"
         super().__init__(message)
 
     # def __str__(self):
