@@ -1,16 +1,18 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 import ast
-import os.path
 import sys
-from pathlib import Path
-from types import SimpleNamespace
-
 import numpy as np
 
+def print_solute(solute):
+    print("Solute:  {name} charge={charge} sigma={sigma} epsilon={eps}".format(**solute))
+
+def print_parameters(params):
+    print("Simulation parameters:")
+    for k, v in params.items():
+        print("  ", k, v)
 
 def print_simulation(solute, solvent_model, params):
-
     print("Solute:")
     print("   {name} charge={charge} sigma={sigma} epsilon={eps}".format(**solute))
     print("Simulation parameters:")
@@ -32,6 +34,10 @@ def print_banner(title):
     print(title)
     print(dash)
 
+def get_banner(title):
+    dash = "-" * len(title)
+    return F"{dash}\n{title}\n{dash}"
+
 
 def iter_lines(fp):
     for line in fp:
@@ -43,7 +49,6 @@ def iter_lines(fp):
 
 
 def read_key_value(filename, section):
-
     tag = f"<{section}>"
 
     params = {}
@@ -68,7 +73,6 @@ def read_key_value(filename, section):
 
 
 def read_solute(filename, section="solute"):
-
     name_list = []
     sigma_list = []
     eps_list = []
@@ -108,7 +112,6 @@ def read_solute(filename, section="solute"):
 
 
 def read_geom(filename, section="geometry"):
-
     name_list = []
     atype_list = []
     x_list = []
@@ -140,7 +143,6 @@ def read_geom(filename, section="geometry"):
 
 
 def read_interaction(filename, section="interactions"):
-
     ff = dict()
     tag = f"<{section}>"
     with open(filename, "r") as fp:
@@ -157,7 +159,6 @@ def read_interaction(filename, section="interactions"):
 
 
 def read_rism_patch(filename, section="rism_patch"):
-
     ff = dict()
     tag = f"<{section}>"
     with open(filename, "r") as fp:
@@ -174,12 +175,11 @@ def read_rism_patch(filename, section="rism_patch"):
 
 
 def read_molecule(
-    filename,
-    geometry_section="geometry",
-    interaction_section="interactions",
-    rism_patch=False,
+        filename,
+        geometry_section="geometry",
+        interaction_section="interactions",
+        rism_patch=False,
 ):
-
     sigma_list = []
     eps_list = []
     charge_list = []
@@ -205,8 +205,8 @@ def read_molecule(
 
     return system
 
-def read_array(filename, section):
 
+def read_array(filename, section):
     tag = f"<{section}>"
 
     with open(filename, "r") as fp:
@@ -214,7 +214,7 @@ def read_array(filename, section):
             # print(f"cannot find {tag} section in {os.path.abspath(filename)}")
             return None, None
         line = fp.readline()
-        nv,ngrid= map(int, line.split())
+        nv, ngrid = map(int, line.split())
         kgrid = np.zeros(shape=ngrid)
         a_k = np.zeros(shape=(nv, nv, ngrid), dtype=np.double)
 
@@ -232,49 +232,8 @@ def read_array(filename, section):
 
         return a_k, kgrid
 
-def read_array_old(nv, ngrid, filename, section):
-
-    tag = f"<{section}>"
-
-    with open(filename, "r") as fp:
-        if find_section(tag, fp) is None:
-            # print(f"cannot find {tag} section in {os.path.abspath(filename)}")
-            return None, None
-        ngrid = int(fp.readline())
-        kgrid = np.zeros(shape=ngrid)
-        a_k = np.zeros(shape=(nv, nv, ngrid), dtype=np.double)
-
-        for ig, line in enumerate(iter_lines(fp)):
-            if line.startswith("<"):
-                break
-            row = list(map(float, line.split()))
-            kgrid[ig] = row[0]
-            n = 1
-            for i in range(nv):
-                for j in range(i, nv):
-                    a_k[i, j, ig] = row[n]
-                    a_k[j, i, ig] = row[n]
-                    n = n + 1
-
-        return a_k, kgrid
-def array_read(nv, ngrid, filename):
-
-    with open(filename, "r") as fp:
-        grid = np.zeros(shape=ngrid)
-        s_k = np.zeros(shape=(nv, ngrid), dtype=np.double)
-
-        for ig, line in enumerate(iter_lines(fp)):
-            row = list(map(float, line.split()))
-            grid[ig] = row[0]
-            n = 1
-            for i in range(nv):
-                s_k[i, ig] = row[i + 1]
-
-        return s_k
-
 
 def find_section(section, fp):
-
     iline = None
     for i, line in enumerate(fp, 1):
         if line.strip() == section:
@@ -283,47 +242,6 @@ def find_section(section, fp):
 
     return iline
 
-def write_matrix_array(filename, grid, matrix, header=None):
-
-    ngrid = matrix.shape[-1]
-    nv = matrix.shape[0]
-
-    with open(filename,"w") as fp:
-        if header:
-            fp.write(F"#{header}\n")
-        for k in range(ngrid):
-            fp.write(F"{grid[k]}   ")
-            for i in range(nv):
-                for j in range(i, nv):
-                    fp.write(F"{matrix[i, j, k]}  ")
-            fp.write("\n")
-
-def write_array(filename, grid, matrix, header=None):
-
-    ngrid = matrix.shape[-1]
-    nv = matrix.shape[0]
-
-    with open(filename,"w") as fp:
-        if header:
-            fp.write(F"#{header}\n")
-        for k in range(ngrid):
-            fp.write(F"{grid[k]}   ")
-            for i in range(nv):
-                    fp.write(F"{matrix[i, k]}  ")
-            fp.write("\n")
-
-def write_array1(filename, grid, matrix, header=None):
-
-    ngrid = matrix.shape[-1]
-    nv = matrix.shape[0]
-
-    with open(filename,"w") as fp:
-        if header:
-            fp.write(F"#{header}\n")
-        for k in range(ngrid):
-            fp.write(F"{grid[k]}   ")
-            fp.write(F"{matrix[k]}  ")
-            fp.write("\n")
 
 # def sim_to_netcdf(sim):
 #
